/*
 * Copyright (C) 2020 ~ 2021 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caixiangrong <caixiangrong@uniontech.com>
 *
 * Maintainer: caixiangrong <caixiangrong@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ERRORTYPE_H
#define ERRORTYPE_H
/**
 * @brief The ErrorType enum 错误码枚举
 */
enum ErrorType {
    // 允许的错误
    Err_NoError = 0, // 无错误
    Err_Allow = 1, // 允许继续
    Err_NoModify = 2, // 没有修改
    // 通用错误
    Err_AllowError = 1000, // 小于这个值的是允许的错误
    Err_Unknown = 1001, // 未知错误 调用DBus/bash等执行了，但执行失败
    Err_NotInit = 1002, // 未初始化
    Err_PowerParamError = 1003, // 电源配置参数错误
    Err_DesktopShortcutsParamError = 1004, // 桌面快捷方式参数错误
    // 文件错误
    Err_IconFormat = 2000, // 创建桌面快捷方式图标格式错误
    Err_IconNotExist = 2001, // 创建桌面快捷方式图标文件不存在
    Err_DesktopDirNotExist = 2002, // 桌面目录不存在
    Err_DownloadFileCreate = 2003, // 文件创建错误 (创建或打开文件时出错)
    Err_FileOpenUnbind = 2004, // 文件打开错误 (打开已存在文件出错)
    Err_FileWriting = 2005, // 写入错误
    // json错误
    Err_JsonParse = 3000, // JSON解析错误
    // 网络错误
    Err_NetworkReply = 4000, // 网络请求错误
    Err_Download = 4001, // 下载错误
    Err_UrlNotSupport = 4002, // 不支持的url类型
    Err_NetworkTimeout = 4003, // 网络请求超时
    // 进程调用错误
    Err_Process = 5000, // 调用进程错误
    Err_Install = 5001, // 安装错误
    // GSetting错误
    Err_GsettingKeyNotExist = 6000, // gsetting无此配置项
    Err_SetGsettingFailed = 6001, // gsetting配置失败
    Err_GetGsettingFailed = 6002, // gsetting获取配置值失败
    Err_S_PowerNotExist = 6003, // GSetting不存在:com.deepin.dde.power
    Err_S_DaemonNotExist = 6004, // GSetting不存在:com.deepin.dde.daemon
    Err_S_DockNotExist = 6005, // GSetting不存在:com.deepin.dde.dock
    Err_S_DockLauncherNotExist = 6006, // GSetting不存在:com.deepin.dde.dock.module.launcher
    Err_S_DockMenuNotExist = 6007, // GSetting不存在:com.deepin.dde.dock.module.menu
    Err_S_DockDockappNotExist = 6008, // GSetting不存在:com.deepin.dde.dock.module.dockapp
    Err_S_DockTrashNotExist = 6009, // GSetting不存在:com.deepin.dde.dock.module.trash
    Err_S_DockNetworkNotExist = 6010, // GSetting不存在:com.deepin.dde.dock.module.network
    Err_S_DiskmountNotExist = 6011, // GSetting不存在:com.deepin.dde.dock.module.disk-mount
    Err_S_ControlCenterNotExist = 6012, // GSetting不存在:com.deepin.dde.control-center
    Err_K_LinePowerScreenBlackDelayNotExist = 6013, // GSetting配置项不存在 :com.deepin.dde.power/linePowerScreenBlackDelay
    Err_K_KeybindingNotExist = 6014, // GSetting配置项不存在 :com.deepin.dde.daemon/keybinding
    Err_K_DisplayModeNotExist = 6015, // GSetting配置项不存在 :com.deepin.dde.dock/displayMode
    Err_K_LauncherEnableNotExist = 6016, // GSetting配置项不存在 :com.deepin.dde.dock.module.launcher/enable
    Err_K_MenuEnableNotExist = 6017, // GSetting配置项不存在 :com.deepin.dde.dock.module.menu/enable
    Err_K_DockappEnableNotExist = 6018, // GSetting配置项不存在 :com.deepin.dde.dock.module.dockapp/enable
    Err_K_TrashEnableNotExist = 6019, // GSetting配置项不存在 :com.deepin.dde.dock.module.trash/enable
    Err_K_NetworkControlNotExist = 6020, // GSetting配置项不存在 :com.deepin.dde.dock.module.network/control
    Err_K_FilemanagerIntegrationNotExist = 6021, // GSetting配置项不存在 :com.deepin.dde.dock.module.disk-mount/filemanagerIntegration
    Err_K_PersonalHotspotNotExist = 6022, // GSetting配置项不存在 :com.deepin.dde.control-center/personalHotspot
    Err_K_HideModuleNotExist = 6023, // GSetting配置项不存在 :com.deepin.dde.control-center/hideModule
    Err_LinePowerScreenBlackDelaySetFailed = 6024, // 设置GSetting : com.deepin.dde.power/linePowerScreenBlackDelay 失败
    Err_KeybindingSetFailed = 6025, // 设置GSetting : com.deepin.dde.daemon/keybinding 失败
    Err_DisplayModeSetFailed = 6026, // 设置GSetting : com.deepin.dde.dock/displayMode 失败
    Err_LauncherEnableSetFailed = 6027, // 设置GSetting : com.deepin.dde.dock.module.launcher/enable 失败
    Err_MenuEnableSetFailed = 6028, // 设置GSetting : com.deepin.dde.dock.module.menu/enable 失败
    Err_DockappEnableSetFailed = 6029, // 设置GSetting : com.deepin.dde.dock.module.dockapp/enable 失败
    Err_TrashEnableSetFailed = 6030, // 设置GSetting : com.deepin.dde.dock.module.trash/enable 失败
    Err_NetworkControlSetFailed = 6031, // 设置GSetting : com.deepin.dde.dock.module.network/control 失败
    Err_FilemanagerIntegrationSetFailed = 6032, // 设置GSetting : com.deepin.dde.dock.module.disk-mount/filemanagerIntegration 失败
    Err_PersonalHotspotSetFailed = 6033, // 设置GSetting : com.deepin.dde.control-center/personalHotspot 失败
    Err_HideModuleSetFailed = 6034, // 设置GSetting : com.deepin.dde.control-center/hideModule 失败
    Err_LinePowerScreenBlackDelayGetFailed = 6035, // 获取GSetting com.deepin.dde.power/linePowerScreenBlackDelay 值失败
    Err_KeybindingGetFailed = 6036, // 获取GSetting com.deepin.dde.daemon/keybinding 值失败
    Err_DisplayModeGetFailed = 6037, // 获取GSetting com.deepin.dde.dock/displayMode 值失败
    Err_LauncherEnableGetFailed = 6038, // 获取GSetting com.deepin.dde.dock.module.launcher/enable 值失败
    Err_MenuEnableGetFailed = 6039, // 获取GSetting com.deepin.dde.dock.module.menu/enable 值失败
    Err_DockappEnableGetFailed = 6040, // 获取GSetting com.deepin.dde.dock.module.dockapp/enable 值失败
    Err_TrashEnableGetFailed = 6041, // 获取GSetting com.deepin.dde.dock.module.trash/enable 值失败
    Err_NetworkControlGetFailed = 6042, // 获取GSetting com.deepin.dde.dock.module.network/control 值失败
    Err_FilemanagerIntegrationGetFailed = 6043, // 获取GSetting com.deepin.dde.dock.module.disk-mount/filemanagerIntegration 值失败
    Err_PersonalHotspotGetFailed = 6044, // 获取GSetting com.deepin.dde.control-center/personalHotspot 值失败
    Err_HideModuleGetFailed = 6045, // 获取GSetting com.deepin.dde.control-center/hideModule 值失败
    // DBus错误
    Err_DBusScreenSaverNotValid = 7000, // com.deepin.ScreenSaver接口不可用
    Err_P_SetScreenSaverTimeoutFailed = 7001, // com.deepin.ScreenSaver接口linePowerScreenSaverTimeout属性设置失败
    Err_P_GetScreenSaverTimeoutFailed = 7002, // com.deepin.ScreenSaver接口linePowerScreenSaverTimeout属性获取失败
    Err_P_SetCurrentScreenSaverFailed = 7003, // com.deepin.ScreenSaver接口currentScreenSaver属性设置失败
    Err_P_GetCurrentScreenSaverFailed = 7004, // com.deepin.ScreenSaver接口currentScreenSaver属性获取失败
    Err_P_SetLockScreenAtAwakeFailed = 7005, // com.deepin.ScreenSaver接口lockScreenAtAwake属性设置失败
    Err_P_GetLockScreenAtAwakeFailed = 7006, // com.deepin.ScreenSaver接口lockScreenAtAwake属性获取失败
    Err_DBusSessionPowerNotValid = 7007, // 用户级com.deepin.daemon.Power接口不可用
    Err_P_SetSleepLockFailed = 7008, // 用户级com.deepin.daemon.Power接口SleepLock属性设置失败
    Err_P_GetSleepLockFailed = 7009, // 用户级com.deepin.daemon.Power接口SleepLock属性获取失败
    Err_DBusAppearanceNotValid = 7010, // com.deepin.daemon.Appearance接口不可用
    Err_M_SetMonitorBackgroundFailed = 7011, // com.deepin.daemon.Appearance接口SetMonitorBackground方法调用失败
    Err_P_GetWallpaperURIsFailed = 7012, // com.deepin.daemon.Appearance接口WallpaperURIs属性获取失败
    Err_DBusKGlobalAccelNotValid = 7013, // org.kde.kglobalaccel接口不可用
    Err_M_BlockGlobalShortcutsFailed = 7014, // org.kde.kglobalaccel接口blockGlobalShortcuts方法调用失败
    Err_DBusSessionNetworkNotValid = 7015, // 用户级com.deepin.daemon.Network接口不可用
    Err_PowerParamOutOfRange = 7016, // 电源配置参数越界
    Err_P_SetPowerDelayPropertyFailed = 7017, // 用户级com.deepin.daemon.Power接口delay属性设置失败
    Err_DBusLogin1NotValid = 7018, // org.freedesktop.login1接口不可用
    Err_M_TerminateUserFailed = 7019, // org.freedesktop.login1接口TerminateUser方法调用失败
    Err_M_PowerOffFailed = 7020, // org.freedesktop.login1接口PowerOff方法调用失败
    Err_M_RebootFailed = 7021, // org.freedesktop.login1接口Reboot方法调用失败
    Err_M_ListUsersFailed = 7022, // org.freedesktop.login1接口ListUsers方法调用失败
    Err_P_StatePropertyFailed = 7023, // org.freedesktop.login1接口State属性获取失败
    Err_DBusAccountsNotValid = 7024, // com.deepin.daemon.Accounts接口不可用
    Err_M_SetLockedFailed = 7025, // com.deepin.daemon.Accounts接口SetLocked方法调用失败
    Err_DBusNetworkManagerNotValid = 7026, // org.freedesktop.NetworkManager接口不可用
    Err_DBusGrub2NotValid = 7027, // com.deepin.daemon.Grub2接口不可用
    Err_M_SetBackgroundSourceFileFailed = 7028, // com.deepin.daemon.Grub2接口SetBackgroundSourceFile方法调用失败
    Err_DBusTimedatedNotValid = 7029, // com.deepin.daemon.Timedated接口不可用
    Err_M_SetNTPServerFailed = 7030, // com.deepin.daemon.Timedated接口SetNTPServer方法调用失败
    Err_M_SetNTPFailed = 7031, // com.deepin.daemon.Timedated接口SetNTP方法调用失败
    Err_DBusAccessControlManagerNotValid = 7032, // com.deepin.filemanager.daemon.AccessControlManager接口不可用
    Err_DBusFileManagerDaemonNotValid = 7033, // com.deepin.filemanager.daemon接口不可用
    Err_M_AccessPolicySetFinishedFailed = 7034, // com.deepin.filemanager.daemon接口AccessPolicySetFinished方法调用失败
    Err_M_SetAccessPolicyFailed = 7035, // com.deepin.filemanager.daemon接口SetAccessPolicy方法调用失败
    Err_DBusIamNotValid = 7036, // com.deepin.udcp.iam接口不可用
    Err_M_RemoveCacheFilesNotInListFailed = 7037, // com.deepin.udcp.iam接口RemoveCacheFilesNotInList方法调用失败
    Err_M_DeleteUserFailed = 7038, // com.deepin.daemon.Accounts接口调用DeleteUser方法失败
    // common错误
    Err_SetScreenSaverTimeFailed = 9000, // SetScreenSaverTime方法调用失败
    Err_SetScreenSaverPolicyFailed = 9001, // SetScreenSaverPolicy方法调用失败
    Err_SetLockScreenAtAwakeFailed = 9002, // SetLockScreenAtAwake方法调用失败
    Err_SetScreenCloseTimeFailed = 9003, // SetScreenCloseTime方法调用失败
    Err_SetMonitorBackgroundFailed = 9004, // SetMonitorBackground方法调用失败
    Err_SetHotspotEnableFailed = 9005, // SetHotspotEnable方法调用失败
    Err_SetUserAutomaticLoginEnableFailed = 9006, // SetUserAutomaticLoginEnable方法调用失败
    Err_SetLoginWithoutPasswordEnableFailed = 9007, // SetLoginWithoutPasswordEnable方法调用失败
    Err_SetBluetoothEnableFailed = 9008, // SetBluetoothEnable方法调用失败
    Err_SetWirelessEnableFailed = 9009, // SetWirelessEnable方法调用失败
    Err_SetCDStateFailed = 9010, // SetCDState方法调用失败
    Err_SetControlConfigFailed = 9011, // SetControlConfig方法调用失败
    Err_SetShortcutKeyEnableFailed = 9012, // SetShortcutKeyEnableFailed方法调用失败
    Err_SetDisplayModeFailed = 9013, // SetDisplayMode方法调用失败
    Err_SetLauncherDisplayableFailed = 9014, // SetLauncherDisplayable方法调用失败
    Err_SetTaskbarRightclickMenuEnableFailed = 9015, // SetTaskbarRightclickMenuEnable方法调用失败
    Err_SetResidentTaskbarAppDisplayableFailed = 9016, // SetResidentTaskbarAppDisplayable方法调用失败
    Err_SetRecycleBinDisplayableFailed = 9017, // SetRecycleBinDisplayable方法调用失败
    Err_SetWebTrayIconClickableFailed = 9018, // SetWebTrayIconClickableFailed方法调用失败
    Err_SetUsbTrayIconClickableFailed = 9019, // SetUsbTrayIconClickableFailed方法调用失败
    Err_SetStorageGlobalPermPolicyTimeOut = 9020, // 调用SetStorageGlobalPermPolicy超时
    Err_SetUserWhiteListFailed = 9021, // setUserWhiteList方法调用失败
    Err_GetActiveUIDFailed = 9022, // GetActiveUID方法调用失败
    // 其他错误
    Err_AMDArch = 60000, // 所安装程序非AMD
    Err_ARMArch = 60001, // 所安装程序非ARM
    Err_MIPSArch = 60002, // 所安装程序非MIPS
    Err_OtherArch = 60003, // 所安装程序与主机不符(主机为AMD、ARM、MIPS以外的架构)
    Err_Version = 60004, // 版本错误，版本与所需的不匹配
    Err_NotMatch = 60005, // 不执行升级，版本或者架构不匹配
    Err_sshStop = 60006, // ssh服务停用错误
};
#endif // ERRORTYPE_H
