/*
 * Copyright (C) 2020 ~ 2021 UnionTech Software Technology Co., Ltd.
 *
 * Author:     yangjianfang <yangjianfang@uniontech.com>
 *
 * Maintainer: yangjianfang <yangjianfang@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef HTTPCLIENTAPI_H
#define HTTPCLIENTAPI_H

#include <QObject>
#include <QEventLoopLocker>
#include <QNetworkAccessManager>

#define LIBUDCPCLIENTAPISHARED_EXPORT Q_DECL_IMPORT

class HttpClientApiPrivate;
class QNetworkReply;
class QThread;
class LIBUDCPCLIENTAPISHARED_EXPORT HttpClientApi : public QObject
{
    Q_OBJECT
public:
    HttpClientApi(QObject *parent = Q_NULLPTR, bool isSupportBreakPoint = false);
    ~HttpClientApi();

    //证书
    void setSSLConfig(const QString &strPath, const QString &strLocalKey, const QString &strPrivateKey);
    //返回超时
    void setReplyTimer(const int &nSecond);

    //同步
    void setRawHeaders(const QMap<QString, QVariant> &headers);
    int getRequest(QString &recvMsg, const QString &strUrl, const QString &strBody = "",
                   bool isSync = true);
    int postRequest(QString &recvMsg, const QString &strUrl, const QString &strBody,
                    bool isSync = true);
    int putRequest(QString &recvMsg, const QString &strUrl, const QString &strBody, bool isSync = true);
    int downloadFile(const QString &fileName, const QString &strUrl, const QString &strBody = "",
                     bool isSync = true, bool bIsSupportBreakPoint = false);
    QNetworkReply *httpRequest(const QString &strUrl, const QByteArray &verb,
                               const QByteArray &strBody, bool bSync = true);
    const QList<QPair<QByteArray, QByteArray>> &getRawHeader();

public Q_SLOTS:
    void onResponseTimeout();

private:
    void deleteReply(QObject *obj);

private:
    QList<QPair<QByteArray, QByteArray>> m_lstRawHeader;
    QNetworkAccessManager *manager;

private:
    const QScopedPointer<HttpClientApiPrivate> d_ptr;
    Q_DECLARE_PRIVATE_D(qGetPtrHelper(d_ptr), HttpClientApi)
};

#endif // HTTPCLIENTAPI_H
