#ifndef UDCPSESSIONINTERFACE_H
#define UDCPSESSIONINTERFACE_H
#include "libudcp-dde_global.h"
#include "udcpsingleton.h"

#include <QString>
#include <QObject>

class QJsonObject;
class QGSettings;
class QDBusInterface;
class UdcpSessionInterfacePrivate;

class LIBUDCPDDESHARED_EXPORT UdcpSessionInterface : public QObject
{
    Q_OBJECT
    UDCP_SINGLETON_DECLARATION(UdcpSessionInterface);

public:
    // 设置屏幕保护时间
    int SetScreenSaverTime(int time);
    // 壁纸设定
    int SetMonitorBackground(QString monitorName, QString imageFile);
    // 获取主屏幕名称
    QString GetPrimaryScreenMonitorName() const;
    // 快捷键使能
    int SetShortcutKeyEnable(bool state);
    // 显示模式设置
    int SetDisplayMode(QString mode);
    // 启动器显示与隐藏
    int SetLauncherDisplayable(bool state);
    // 任务栏右键菜单启用与禁用
    int SetTaskbarRightclickMenuEnable(bool state);
    // 驻留任务栏应用显示与隐藏
    int SetResidentTaskbarAppDisplayable(bool state);
    // 右下角任务栏回收站显示与隐藏
    int SetRecycleBinDisplayable(bool state);
    // 网络托盘图标可点击启用与禁用
    int SetWebTrayIconClickable(bool state);
    // usb托盘图标双击打开访问启用与禁用
    int SetUsbTrayIconClickable(bool state);
    // 禁用或启用个人热点，enable 0-关闭，1-开启
    int SetHotspotEnable(const int enable);
    // 获取个人热点状态 0-关闭，1-开启
    int GetHotspotEnable();
    // 使用电池设置自动锁屏时间(s)
    int SetBatteryLockDelay(const int seconds);
    // 获取使用电池自动锁屏时间
    int GetBatteryLockDelay();
    // 使用电池设置关闭显示器时间(s)
    int SetBatteryScreenBlackDelay(const int seconds);
    // 获取使用电池关闭显示器时间
    int GetBatteryScreenBlackDelay();
    // 使用电池设置进入待机时间(s)
    int SetBatterySleepDelay(const int seconds);
    // 获取使用电池进入待机时间
    int GetBatterySleepDelay();
    // 使用电源设置自动锁屏时间(s)
    int SetPowerLockDelay(const int seconds);
    // 获取使用电源自动锁屏时间
    int GetPowerLockDelay();
    // 使用电源设置关闭显示器时间(s)
    int SetPowerScreenBlackDelay(const int seconds);
    // 获取使用电源关闭显示器时间
    int GetPowerScreenBlackDelay();
    // 使用电源设置进入待机时间(s)
    int SetPowerSleepDelay(const int seconds);
    // 获取使用电源进入待机时间
    int GetPowerSleepDelay();
    // 电源管理设置总接口
    int SetPower(const QJsonObject &config);
    // 获取电源管理配置总接口
    QJsonObject GetPower();
    // 具体实现 在当前用户桌面上创建网络快捷方式
    int CreateDesktopNetAddress(QString name, QString iconPath, QString url);
    // 屏保启用时间配置
    int SetScreenSaverPolicy(const QString &path);
    // 设置控制中心所有功能模块显示隐藏配置
    int SetControlConfig(const QStringList &allConfig, const QStringList &hideList, bool isDomain = true);
    // 获取控制中心隐藏功能列表
    QStringList GetHideModule();
    // 是否隐藏修改密码选项
    QString HideModifuPasswd(bool status);
    // 设置屏保唤醒是否需要密码
    int SetLockScreenAtAwake(bool status);
    // 注销账户
    int Logout();

private:
    UdcpSessionInterfacePrivate *d_ptr;

    Q_DECLARE_PRIVATE_D(qGetPtrHelper(d_ptr), UdcpSessionInterface)
};

#endif // UDCPSESSIONINTERFACE_H
