/*
 * Copyright (C) 2020 ~ 2021 UnionTech Software Technology Co., Ltd.
 *
 * Author:     caixiangrong <caixiangrong@uniontech.com>
 *
 * Maintainer: caixiangrong <caixiangrong@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef UDCPSINGLETON_H
#define UDCPSINGLETON_H
/**
 * @brief 单例声明宏，放在声明中
 * 饿汉模式，线程安全
 * 注：无参数构造函数已声明，需自己实现
 * @param ClassName 对应的类
 */
#define UDCP_SINGLETON_DECLARATION(ClassName) \
public: \
    static ClassName* Instance(void)\
    {\
        static ClassName s_instance;\
        return &s_instance;\
    }\
private: \
    ClassName(ClassName const&){} \
    ClassName& operator=(ClassName const&){return *this;} \
    ClassName()

#endif // UDCPSINGLETON_H
