#ifndef UDCPSYSTEMINTERFACE_H
#define UDCPSYSTEMINTERFACE_H
#include "libudcp-dde_global.h"
#include "udcpsingleton.h"

#include <QString>
#include <QObject>

class QDBusInterface;
class UdcpSystemInterfacePrivate;

class LIBUDCPDDESHARED_EXPORT UdcpSystemInterface : public QObject
{
    Q_OBJECT
    UDCP_SINGLETON_DECLARATION(UdcpSystemInterface);

public:
    // e.用户自动登陆使能
    int SetUserAutomaticLoginEnable(bool state);
    // f.无密码登陆使能
    int SetLoginWithoutPasswordEnable(bool state);
    // 10.开启或关闭蓝牙功能
    int SetBluetoothEnable(const bool state);
    bool GetBluetoothEnable() const;
    // 11.开启或关闭无线网络功能
    int SetWirelessEnable(const bool state);
    bool GetWirelessEnable() const;
    // 12.远程开启重启
    int Shutdown();
    //
    int Reboot();
    // dbus接口 查询当前系统激活状态
    int GetSystemAuthorizationStatus();
    // dbus接口 查询当前是否开发者模式
    int GetDeveloperModeStatus();
    // 15.启动页背景图片配置
    int SetBackgroundSourceFile(const QString path);
    // 设置时间同步服务
    int SetNTPServer(QString server);
    // 获得时间同步的服务
    QString GetNTPServer();
    // 设置密码规则信息
    int SetPasswordConfig(QString passwdInfo);
    // 设置本地账户户登录限制 ,执行成功 QString返回值为空
    int SetLocalUserLogoinLimit(bool enable);
    // 设置应用管控黑名单
    int SetAppCtrlBlacklist(const QString &pkgNameListStr);
    // mode: 设置权限 文管协定：0--禁用，1--只读， 2--可读可写
    int SetStorageGlobalPermPolicy(const int type, const int mode);
    // 清理单个用户缓存信息
    int clearUserCachebyUid(const QString &uid);
    // 清理白名单以外的用户缓存信息
    int setUserWhiteList(const QList<quint32> &uids);
    // 设置账号锁定时间和次数 时间分钟单位
    int SetLADPLockTimeAndNum(int time, int num);
    // 重新设置锁定时间 当退域的时候
    int RestoreLockLimitByQuitDomain();
    // 获取本地账户uid列表
    QList<int> GetLocalUIDList();
    // 删除网络账户
    int DeleteUdcpUser(const QString &uid);
private slots:
    void SetWirelessDeviceEnable();
    void SetWirelessDeviceDisable();

private:
    UdcpSystemInterfacePrivate *d_ptr;

    Q_DECLARE_PRIVATE_D(qGetPtrHelper(d_ptr), UdcpSystemInterface)
};

#endif // UDCPSYSTEMINTERFACE_H
