/*
 * Copyright (C) 2020 ~ 2021 UnionTech Software Technology Co., Ltd.
 *
 * Author:     yangjianfang <yangjianfang@uniontech.com>
 *
 * Maintainer: yangjianfang <yangjianfang@uniontech.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include <QObject>
#include <QSslConfiguration>
#include <QUrl>

class QWebSocket;
class QDBusInterface;
class QTimer;

class WebSocketApi : public QObject
{
    Q_OBJECT
private:
    // 网络状态枚举，详细解释参考 https://developer.gnome.org/NetworkManager/stable/nm-dbus-types.html#NMState
    enum NMState {
        NM_STATE_UNKNOWN = 0, // 未知网络状态
        NM_STATE_ASLEEP = 10, // 网络未启用
        NM_STATE_DISCONNECTED = 20, // 无可用网络
        NM_STATE_DISCONNECTING = 30, // 网络连接断开中
        NM_STATE_CONNECTING = 40, // 网络正在连接中
        NM_STATE_CONNECTED_LOCAL = 50, // 本地网络连接成功，但没有访问Internet的默认路由
        NM_STATE_CONNECTED_SITE = 60, // 网络连接成功，但Internet连接检查未成功
        NM_STATE_CONNECTED_GLOBAL = 70 // 网络连接检查成功，可以访问Internet
    };

public:
    explicit WebSocketApi(QObject *parent = nullptr);
    ~WebSocketApi();
    void setSslConfig(const QString &serverCertPath, const QString &publicKeyPath, const QString &privateKeyPath);
    void connectServer(const QUrl &url);

Q_SIGNALS:
    void messageReceived(const QString &message);

private:
    bool setLocalCertificate(const QString &path);
    bool setPrivateKey(const QString &path);
    bool setCaCertificates(const QString &path);

private Q_SLOTS:
    void onStateChanged(const uint state);
    void onDisconnected();
    void onConnected();
    void onPing();
    void onPong(quint64 elapsedTime, const QByteArray &payload);
    void onTextMessageReceived(const QString &messag);
    void onBinaryMessageReceived(const QByteArray &message);

private:
    QDBusInterface *m_networkInterface;
    QWebSocket *m_webSocket;
    int m_retryCount; // ping失败重试次数
    uint m_networkState; // 当前系统网络状态
    QSslConfiguration m_sslConfig;
    QUrl m_url; // 当前webserver链接地址
    QTimer *m_pingTimer; // 保持与服务端连接的定时器
};
